@@ -175,6 +175,7 @@ class FMRadio(object):
         self.__freq_range = (self.__tuner["rangelow"] / self.__factor,
                              self.__tuner["rangehigh"] / self.__factor)
 
+
         self.set_mute(False)
 
         
@@ -279,7 +280,7 @@ class FMRadio(object):
         """
     
         low, high = self.__freq_range
-        return (low, high)
+        return (76000, 108000)
         
         
     def get_frequency(self):
@@ -309,7 +310,7 @@ class FMRadio(object):
 
         low, high = self.__freq_range
         # a frequency of 0 tells the FM tuner to power down
-        assert(freq == 0 or low <= freq <= high)
+        assert(freq == 0 or 76000 <= freq <= 108000)
 
         inp = struct.pack("LLL8L",
                           self.__tuner["index"],
